@@ -2,7 +2,7 @@
 **  Copyright (c) 2007 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2012, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_CACHE_H_
@@ -14,10 +14,6 @@
 
 #ifdef QUERY_CACHE
 
-#ifndef lint
-static char dkim_cache_h_id[] = "@(#)$Id: dkim-cache.h,v 1.2 2009/11/22 08:15:50 grooverdan Exp $";
-#endif /* !lint */
-
 /* libdb includes */
 #include <db.h>
 
