@@ -2,13 +2,9 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.18.10.1 2010/10/27 21:43:08 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/param.h>
 #include <sys/types.h>
@@ -32,7 +28,11 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.18.10.1 2010/10/27 21:4
 #include "dkim-cache.h"
 #include "dkim-test.h"
 #include "util.h"
-#include "dkim-strl.h"
+
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 /* prototypes */
 extern void dkim_error __P((DKIM *, const char *, ...));
@@ -95,7 +95,6 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	assert(sig != NULL);
 	assert(sig->sig_selector != NULL);
 	assert(sig->sig_domain != NULL);
-	assert(sig->sig_query == DKIM_QUERY_DNS);
 
 	lib = dkim->dkim_libhandle;
 
@@ -136,6 +135,14 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		timeout.tv_sec = dkim->dkim_timeout;
 		timeout.tv_usec = 0;
 
+		if (lib->dkiml_dns_service == NULL &&
+		    lib->dkiml_dns_init != NULL &&
+		    lib->dkiml_dns_init(&lib->dkiml_dns_service) != 0)
+		{
+			dkim_error(dkim, "cannot initialize resolver");
+			return DKIM_STAT_KEYFAIL;
+		}
+
 		status = lib->dkiml_dns_start(lib->dkiml_dns_service, T_TXT,
 		                              qname, ansbuf, anslen, &q);
 
