@@ -2,13 +2,9 @@
 **  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.13.10.1 2010/10/27 21:43:08 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -37,7 +33,11 @@ static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.13.10.1 2010/10/27
 #endif /* QUERY_CACHE */
 #include "dkim-test.h"
 #include "util.h"
-#include "dkim-strl.h"
+
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 /* prototypes */
 extern void dkim_error __P((DKIM *, const char *, ...));
@@ -197,6 +197,15 @@ dkim_get_policy_dns_excheck(DKIM *dkim, unsigned char *query, int *qstatus)
 	timeout.tv_sec = dkim->dkim_timeout;
 	timeout.tv_usec = 0;
 
+	if (lib->dkiml_dns_service == NULL &&
+	    lib->dkiml_dns_init != NULL &&
+	    lib->dkiml_dns_init(&lib->dkiml_dns_service) != 0)
+	{
+		dkim_error(dkim, "resolver initialization failed for '%s'",
+		           query);
+		return -1;
+	}
+
 	anslen_a = sizeof ansbuf_a;
 	status = lib->dkiml_dns_start(lib->dkiml_dns_service, T_A, query,
 	                              ansbuf_a, anslen_a, &q_a);
@@ -377,7 +386,7 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, _Bool excheck,
 	int qdcount;
 	int ancount;
 	int status;
-	int rdlength;
+	int rdlength = 0;
 	int n;
 	int c;
 	int type = -1;
@@ -440,6 +449,16 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, _Bool excheck,
 
 		anslen = sizeof ansbuf;
 
+		if (lib->dkiml_dns_service == NULL &&
+		    lib->dkiml_dns_init != NULL &&
+		    lib->dkiml_dns_init(&lib->dkiml_dns_service) != 0)
+		{
+			dkim_error(dkim,
+			           "resolver initialization failed for '%s'",
+			           query);
+			return -1;
+		}
+
 		status = lib->dkiml_dns_start(lib->dkiml_dns_service,
 		                              T_TXT, query,
 		                              ansbuf, anslen, &q);
