@@ -2,16 +2,12 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_TYPES_H_
 #define _DKIM_TYPES_H_
 
-#ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.23 2010/10/28 02:41:25 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -51,11 +47,19 @@ static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.23 2010/10/28 02:41:2
 #include "dkim.h"
 #include "dkim-internal.h"
 
+/* struct dkim_qmethod -- signature query method */
+struct dkim_qmethod
+{
+	char *			qm_type;
+	char *			qm_options;
+	struct dkim_qmethod *	qm_next;
+};
+
 /* struct dkim_xtag -- signature extension tag */
 struct dkim_xtag
 {
-	const char *		xt_tag;
-	const char *		xt_value;
+	char *			xt_tag;
+	char *			xt_value;
 	struct dkim_xtag *	xt_next;
 };
 
@@ -150,6 +154,7 @@ struct dkim_siginfo
 	struct dkim_canon *	sig_bodycanon;
 	struct dkim_set *	sig_taglist;
 	struct dkim_set *	sig_keytaglist;
+	struct dkim_dstring *	sig_sslerrbuf;
 };
 
 #ifdef USE_GNUTLS
@@ -293,7 +298,7 @@ struct dkim
 	size_t			dkim_keylen;
 	size_t			dkim_errlen;
 	uint64_t		dkim_timestamp;
-	dkim_query_t		dkim_querymethod;
+  	struct dkim_qmethod *	dkim_querymethods;
 	dkim_canon_t		dkim_hdrcanonalg;
 	dkim_canon_t		dkim_bodycanonalg;
 	dkim_alg_t		dkim_signalg;
@@ -335,6 +340,7 @@ struct dkim
 	struct dkim_canon *	dkim_canontail;
 	struct dkim_dstring *	dkim_hdrbuf;
 	struct dkim_dstring *	dkim_canonbuf;
+	struct dkim_dstring *	dkim_sslerrbuf;
 	struct dkim_test_dns_data * dkim_dnstesth;
 	struct dkim_test_dns_data * dkim_dnstestt;
 	DKIM_LIB *		dkim_libhandle;
@@ -345,12 +351,12 @@ struct dkim_lib
 {
 	_Bool			dkiml_signre;
 	_Bool			dkiml_skipre;
+	_Bool			dkiml_dnsinit_done;
 	u_int			dkiml_flags;
 	u_int			dkiml_timeout;
 	u_int			dkiml_version;
 	u_int			dkiml_callback_int;
 	u_int			dkiml_flsize;
-	u_int			dkiml_nalwayshdrs;
 	u_int			dkiml_minkeybits;
 	uint64_t		dkiml_fixedtime;
 	uint64_t		dkiml_sigttl;
@@ -360,7 +366,7 @@ struct dkim_lib
 	void *			(*dkiml_malloc) (void *closure, size_t nbytes);
 	void			(*dkiml_free) (void *closure, void *p);
 	u_char **		dkiml_senderhdrs;
-	u_char **		dkiml_alwayshdrs;
+	u_char **		dkiml_requiredhdrs;
 	u_char **		dkiml_oversignhdrs;
 	u_char **		dkiml_mbs;
 #ifdef QUERY_CACHE
@@ -393,12 +399,19 @@ struct dkim_lib
 				                int nsigs);
 	void			(*dkiml_dns_callback) (const void *context);
 	void			*dkiml_dns_service;
+	int			(*dkiml_dns_init) (void **srv);
+	void			(*dkiml_dns_close) (void *srv);
 	int			(*dkiml_dns_start) (void *srv, int type,
 				                    unsigned char *query,
 				                    unsigned char *buf,
 				                    size_t buflen,
 				                    void **qh);
 	int			(*dkiml_dns_cancel) (void *srv, void *qh);
+	int			(*dkiml_dns_setns) (void *srv, const char *ns);
+	int			(*dkiml_dns_config) (void *srv,
+				                     const char *conf);
+	int			(*dkiml_dns_trustanchor) (void *srv,
+				                          const char *ta);
 	int			(*dkiml_dns_waitreply) (void *srv,
 				                        void *qh,
 				                        struct timeval *to,
