@@ -2,7 +2,7 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 */
 
 #ifndef _DKIM_H_
@@ -12,10 +12,6 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.36.2.1 2010/10/27 21:43:08 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/types.h>
 #include <sys/param.h>
@@ -34,7 +30,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.36.2.1 2010/10/27 21:43:08 cm-msk
 **  	pp == patch number
 */
 
-#define	OPENDKIM_LIB_VERSION	0x02060800
+#define	OPENDKIM_LIB_VERSION	0x02070300
 
 #ifdef __STDC__
 # ifndef __P
@@ -100,6 +96,7 @@ typedef int DKIM_CBSTAT;
 #define	DKIM_CBSTAT_TRYAGAIN	2	/* try again later */
 #define	DKIM_CBSTAT_NOTFOUND	3	/* requested record not found */
 #define	DKIM_CBSTAT_ERROR	4	/* error requesting record */
+#define	DKIM_CBSTAT_DEFAULT	5	/* bypass; use default handling */
 
 /*
 **  DKIM_SIGERROR -- signature errors
@@ -161,6 +158,7 @@ typedef int DKIM_SIGERROR;
 #define	DKIM_DNS_SUCCESS	0		/* reply available */
 #define	DKIM_DNS_NOREPLY	1		/* reply not available (yet) */
 #define	DKIM_DNS_EXPIRED	2		/* no reply, query expired */
+#define	DKIM_DNS_INVALID	3		/* invalid request */
 
 /*
 **  DKIM_CANON -- canonicalization method
@@ -270,11 +268,12 @@ typedef int dkim_opts_t;
 #define	DKIM_OPTS_QUERYINFO	7
 #define	DKIM_OPTS_FIXEDTIME	8
 #define	DKIM_OPTS_SKIPHDRS	9
-#define	DKIM_OPTS_ALWAYSHDRS	10
+#define	DKIM_OPTS_ALWAYSHDRS	10	/* obsolete */
 #define	DKIM_OPTS_SIGNATURETTL	11
 #define	DKIM_OPTS_CLOCKDRIFT	12
 #define	DKIM_OPTS_MUSTBESIGNED	13
 #define	DKIM_OPTS_MINKEYBITS	14
+#define	DKIM_OPTS_REQUIREDHDRS	15
 
 #define	DKIM_LIBFLAGS_NONE		0x0000
 #define	DKIM_LIBFLAGS_TMPFILES		0x0001
@@ -1200,6 +1199,19 @@ extern void *dkim_sig_getcontext __P((DKIM_SIGINFO *siginfo));
 
 extern int dkim_sig_geterror __P((DKIM_SIGINFO *siginfo));
 
+/*
+**  DKIM_SIG_SETERROR -- set error code in a DKIM_SIGINFO
+**
+**  Parameters:
+**  	siginfo -- a pointer to a DKIM_SIGINFO
+** 	err -- error code
+**
+**  Return value:
+**  	A DKIM_STAT_* constant.
+*/
+
+extern DKIM_STAT dkim_sig_seterror __P((DKIM_SIGINFO *siginfo, int err));
+
 /*
 **  DKIM_SIG_GETERRORSTR -- translate a DKIM_SIGERROR into a string
 **
@@ -1671,38 +1683,6 @@ extern u_char *dkim_sig_gettagvalue __P((DKIM_SIGINFO *, _Bool, u_char *));
 extern DKIM_STAT dkim_sig_getsignedhdrs __P((DKIM *, DKIM_SIGINFO *,
                                              u_char *, size_t, u_int *));
 
-/*
-**  DKIM_STRLCPY -- size-bounded strcpy()
-**
-**  Parameters:
-**  	dst -- destination string
-** 	src -- source string
-**  	len -- total length of buffer at "dst"
-**
-**  Return value:
-**  	Number of bytes needed to complete the copy, including the terminating
-**  	NULL.  If this is greater than or equal to "len", truncation occurred
-**  	as this function guarantees "dst" will always be NULL-terminated.
-*/
-
-extern size_t dkim_strlcpy __P((char *, const char *, ssize_t));
-
-/*
-**  DKIM_STRLCAT -- size-bounded strcat()
-**
-**  Parameters:
-**  	dst -- destination string
-** 	src -- source string
-**  	len -- total length of buffer at "dst"
-**
-**  Return value:
-**  	Total length of the string the caller tried to create, including
-**  	leaving a trailng NULL.  If this is greater than or equal to "len",
-**  	truncation occurred.
-*/
-
-extern size_t dkim_strlcat __P((char *, const char *, ssize_t));
-
 /*
 **  DKIM_QP_DECODE -- decode a quoted-printable string
 **
@@ -1808,6 +1788,190 @@ extern void dkim_dns_set_query_waitreply __P((DKIM_LIB *,
                                                       size_t *, int *,
                                                       int *)));
 
+/*
+**  DKIM_DNS_SET_INIT -- initializes the resolver
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	func -- function to use to initialize the resolver
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int (status)
+**  		void **srv -- DNS service handle (updated)
+*/
+
+extern void dkim_dns_set_init __P((DKIM_LIB *,
+                                   int (*)(void **)));
+
+/*
+**  DKIM_DNS_SET_CLOSE -- shuts down the resolver
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	func -- function to use to shut down the resolver
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns void
+**  		void *srv -- DNS service handle
+*/
+
+extern void dkim_dns_set_close __P((DKIM_LIB *,
+                                    void (*)(void *)));
+
+/*
+**  DKIM_DNS_SET_NSLIST -- set function that updates resolver nameserver list
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	func -- function to use to update the nameserver list
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int
+**  		void *srv -- DNS service handle
+**  		const char *nslist -- nameserver list, as a comma-separated
+**  			string
+*/
+
+extern void dkim_dns_set_nslist __P((DKIM_LIB *,
+                                     int (*)(void *, const char *)));
+
+/*
+**  DKIM_DNS_SET_CONFIG -- set function that passes configuration data to
+**                         the active resolver
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	func -- function to use to configure the active resolver
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int
+**  		void *srv -- DNS service handle
+**  		const char *config -- arbitrary configuration data
+*/
+
+extern void dkim_dns_set_config __P((DKIM_LIB *,
+                                     int (*)(void *, const char *)));
+
+/*
+**  DKIM_DNS_SET_TRUSTANCHOR -- set function that passes trust anchor data to
+**                              the active resolver
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	func -- function to use to pass trust anchor data to the resolver
+**
+**  Return value:
+**  	None.
+**
+**  Notes:
+**  	"func" should match the following prototype:
+**  		returns int
+**  		void *srv -- DNS service handle
+**  		const char *trustanchor -- arbitrary trust anchor data
+*/
+
+extern void dkim_dns_set_trustanchor __P((DKIM_LIB *,
+                                          int (*)(void *, const char *)));
+
+/*
+**  DKIM_DNS_NSLIST -- update resolver nameserver list
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	nslist -- comma-separated nameserver list, as IP addresses
+**
+**  Return value:
+**  	A DKIM_DNS_* constant.
+**
+**  Notes:
+**  	The underlying API may not return a failure status, in which case
+**  	this always returns DKIM_DNS_SUCCESS.  The underlying API might also
+**  	not use all of the nameservers provided.
+*/
+
+extern int dkim_dns_nslist __P((DKIM_LIB *, const char *));
+
+/*
+**  DKIM_DNS_INIT -- force resolver (re)initialization
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**
+**  Return value:
+**  	A DKIM_DNS_* constant.
+*/
+
+extern int dkim_dns_init __P((DKIM_LIB *));
+
+/*
+**  DKIM_DNS_CLOSE -- force resolver shutdown
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**
+**  Return value:
+**  	A DKIM_DNS_* constant.
+*/
+
+extern int dkim_dns_close __P((DKIM_LIB *));
+
+/*
+**  DKIM_DNS_CONFIG -- requests a change to resolver configuration
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	config -- opaque configuration string
+**
+**  Return value:
+**  	A DKIM_DNS_* constant.
+*/
+
+extern int dkim_dns_config __P((DKIM_LIB *, const char *));
+
+/*
+**  DKIM_DNS_TRUSTANCHOR -- requests a change to trust anchor configuration
+**
+**  Parameters:
+**  	lib -- DKIM library handle
+**  	trust -- opaque trust anchor string
+**
+**  Return value:
+**  	A DKIM_DNS_* constant.
+*/
+
+extern int dkim_dns_trustanchor __P((DKIM_LIB *, const char *));
+
+/*
+**  DKIM_ADD_QUERYMETHOD -- add a query method
+**
+**  Parameters:
+**  	dkim -- DKIM signing handle to extend
+**  	type -- type of query to add
+**  	options -- options to include
+**
+**  Return value:
+**  	A DKIM_STAT_* constant.
+*/
+
+extern DKIM_STAT dkim_add_querymethod __P((DKIM *, const char *,
+                                           const char *));
+
 /*
 **  DKIM_ADD_XTAG -- add an extension tag/value
 **
@@ -1914,6 +2078,30 @@ extern int dkim_base32_encode __P((char *, size_t *, const void *, size_t));
 extern DKIM_STAT dkim_sig_gethashes __P((DKIM_SIGINFO *, void **, size_t *,
                                          void **, size_t *));
 
+/*
+**  DKIM_GETSSLBUF -- get the SSL error buffer, if any, from a DKIM handle
+**
+**  Parameters:
+**  	dkim -- DKIM handle from which to get SSL error
+**
+**  Return value:
+**  	Pointer to the string, if defined, or NULL otherwise.
+*/
+
+extern const char *dkim_getsslbuf __P((DKIM *dkim));
+
+/*
+**  DKIM_SIG_GETSSLBUF -- get the SSL error buffer, if any, from a signature
+**
+**  Parameters:
+**  	sig -- signature handle from which to get SSL error
+**
+**  Return value:
+**  	Pointer to the string, if defined, or NULL otherwise.
+*/
+
+extern const char *dkim_sig_getsslbuf __P((DKIM_SIGINFO *sig));
+
 /* default list of sender headers */
 extern const u_char *dkim_default_senderhdrs[];
 
