@@ -2,13 +2,10 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2011, 2012, The Trusted Domain Project.
+**    All rights reserved.
 */
 
-#ifndef lint
-static char t_test127_c_id[] = "@(#)$Id: t-test127.c,v 1.2 2009/12/08 19:14:27 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -23,9 +20,13 @@ static char t_test127_c_id[] = "@(#)$Id: t-test127.c,v 1.2 2009/12/08 19:14:27 c
 
 /* libopendkim includes */
 #include "../dkim.h"
-#include "../dkim-strl.h"
 #include "t-testdata.h"
 
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
+
 #define	MAXHEADER	4096
 
 #define	MAXMSGSIZE	16384
@@ -118,12 +119,12 @@ main(int argc, char **argv)
 
 	memset(buf, '\0', sizeof buf);
 
-	dkim_strlcpy(buf, CRLFBODY00, sizeof buf);
+	strlcpy(buf, CRLFBODY00, sizeof buf);
 
 	while (strlen(buf) < BOUNDARY)
-		dkim_strlcat(buf, CRLF, sizeof buf);
+		strlcat(buf, CRLF, sizeof buf);
 
-	dkim_strlcat(buf, CRLFBODY00, sizeof buf);
+	strlcat(buf, CRLFBODY00, sizeof buf);
 
 	assert(strlen(buf) > BOUNDARY);
 
