@@ -2,13 +2,10 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2011, 2012, The Trusted Domain Project.
+**    All rights reserved.
 */
 
-#ifndef lint
-static char t_test55_c_id[] = "@(#)$Id: t-test55.c,v 1.2 2009/12/08 19:14:27 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -23,9 +20,13 @@ static char t_test55_c_id[] = "@(#)$Id: t-test55.c,v 1.2 2009/12/08 19:14:27 cm-
 
 /* libopendkim includes */
 #include "../dkim.h"
-#include "../dkim-strl.h"
 #include "t-testdata.h"
 
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
+
 #define	MAXHEADER	4096
 
 #define	GIBBERISHLEN	(sizeof(GIBBERISH) - 1)
