@@ -2,13 +2,10 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2011, 2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2011, 2012, The Trusted Domain Project.
+**    All rights reserved.
 */
 
-#ifndef lint
-static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.2 2009/12/08 19:14:27 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -30,6 +27,11 @@ static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.2 2009/12/08 19:14:27 cm-
 #include "../dkim.h"
 #include "t-testdata.h"
 
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
+
 #define	BUFRSZ		1024
 #define	MAXADDRESS	256
 #define	MAXHEADER	4096
@@ -56,7 +58,7 @@ stub_dns_query(void *srv, int type, unsigned char *query,
 {
 	abuf = buf;
 	alen = buflen;
-	dkim_strlcpy(qbuf, query, sizeof qbuf);
+	strlcpy(qbuf, query, sizeof qbuf);
 
 	return DKIM_DNS_SUCCESS;
 }
