@@ -2,15 +2,10 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2011, 2012, The Trusted Domain Project.
+**    All rights reserved.
 */
 
-#ifndef lint
-static char t_test84_c_id[] = "@(#)$Id: t-test84.c,v 1.2.38.1 2010/10/28 04:25:38 cm-msk Exp $";
-#endif /* !lint */
-
-#include "build-config.h"
-
 #include "build-config.h"
 
 /* system includes */
@@ -30,7 +25,11 @@ static char t_test84_c_id[] = "@(#)$Id: t-test84.c,v 1.2.38.1 2010/10/28 04:25:3
 /* libopendkim includes */
 #include "../dkim.h"
 #include "t-testdata.h"
-#include "../dkim-strl.h"
+
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 #define	MAXHEADER	4096
 
