@@ -1,11 +1,7 @@
 /*
-**  Copyright (c) 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2011, 2012, The Trusted Domain Project.  All rights reserved.
 */
 
-#ifndef lint
-static char flowrate_c_id[] = "@(#)$Id$";
-#endif /* !lint */
-
 #include "build-config.h"
 
 #ifdef _FFR_RATE_LIMIT
@@ -20,8 +16,10 @@ static char flowrate_c_id[] = "@(#)$Id$";
 #include <string.h>
 #include <stdlib.h>
 
-/* libopendkim includes */
-#include <dkim-strl.h>
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 /* opendkim includes */
 #include "flowrate.h"
