@@ -2,18 +2,13 @@
 **  Copyright (c) 2006-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: opendkim-config.h,v 1.32.10.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
-#ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: opendkim-config.h,v 1.32.10.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -35,7 +30,6 @@ struct configdef dkimf_config[] =
 	{ "ADSPNoSuchDomain",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AllowSHA1Only",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysAddARHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
-	{ "AlwaysSignHeaders",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_ATPS
 	{ "ATPSDomains",		CONFIG_TYPE_STRING,	FALSE },
 	{ "ATPSHashAlgorithm",		CONFIG_TYPE_STRING,	FALSE },
@@ -80,12 +74,12 @@ struct configdef dkimf_config[] =
 	{ "FinalPolicyScript",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* USE_LUA */
 	{ "FixCRLF",			CONFIG_TYPE_BOOLEAN,	FALSE },
-#ifdef _FFR_IDENTITY_HEADER
 #ifdef _FFR_RATE_LIMIT
 	{ "FlowData",			CONFIG_TYPE_STRING,	FALSE },
 	{ "FlowDataFactor",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "FlowDataTTL",		CONFIG_TYPE_INTEGER,	FALSE },
 #endif /* _FFR_RATE_LIMIT */
+#ifdef _FFR_IDENTITY_HEADER
 	{ "IdentityHeader",		CONFIG_TYPE_STRING,     FALSE },
 	{ "IdentityHeaderRemove",	CONFIG_TYPE_BOOLEAN,    FALSE },
 #endif /* _FFR_IDENTITY_HEADER */
@@ -130,6 +124,7 @@ struct configdef dkimf_config[] =
 	{ "MTA",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MTACommand",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MustBeSigned",		CONFIG_TYPE_STRING,	FALSE },
+	{ "Nameservers",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_ADSP_LISTS
 	{ "NoDiscardableMailTo",	CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_ADSP_LISTS */
@@ -146,9 +141,7 @@ struct configdef dkimf_config[] =
 	{ "On-ReputationError",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_REPUTATION */
 	{ "On-Security",		CONFIG_TYPE_STRING,	FALSE },
-#ifdef _FFR_OVERSIGN
 	{ "OverSignHeaders",		CONFIG_TYPE_STRING,	FALSE },
-#endif /* _FFR_OVERSIGN */
 	{ "PeerList",			CONFIG_TYPE_STRING,	FALSE },
 	{ "PidFile",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef POPAUTH
@@ -181,8 +174,18 @@ struct configdef dkimf_config[] =
 	{ "ReputationMinimum",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "ReputationLimitModifiers",	CONFIG_TYPE_STRING,	FALSE },
 	{ "ReputationRatios",		CONFIG_TYPE_STRING,	FALSE },
+#endif /* _FFR_REPUTATION */
+#ifdef _FFR_REPRRD
+	{ "ReputationRRDHashDepth",	CONFIG_TYPE_INTEGER,	FALSE },
+	{ "ReputationRRDRoot",		CONFIG_TYPE_STRING,	FALSE },
+	{ "ReputationTest", /* DUP */	CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "ReputationVerbose", /* DUP */ CONFIG_TYPE_BOOLEAN,	FALSE },
+#endif /* _FFR_REPRRD */
+#ifdef _FFR_REPUTATION
 	{ "ReputationSpamCheck",	CONFIG_TYPE_STRING,	FALSE },
+	{ "ReputationTest",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "ReputationTimeFactor",	CONFIG_TYPE_INTEGER,	FALSE },
+	{ "ReputationTimeout",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "ReputationVerbose",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #endif /* _FFR_REPUTATION */
 	{ "RequestReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
@@ -192,9 +195,7 @@ struct configdef dkimf_config[] =
 	{ "ResignAll",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "ResignMailTo",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_RESIGN */
-#ifdef USE_UNBOUND
-	{ "ResolvConf",			CONFIG_TYPE_STRING,	FALSE },
-#endif /* USE_UNBOUND */
+	{ "ResolverConfiguration",	CONFIG_TYPE_STRING,	FALSE },
 	{ "ResolverTracing",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef USE_LUA
 	{ "ScreenPolicyScript",		CONFIG_TYPE_STRING,	FALSE },
@@ -215,6 +216,7 @@ struct configdef dkimf_config[] =
 	{ "SignHeaders",		CONFIG_TYPE_STRING,	FALSE },
 	{ "SigningTable",		CONFIG_TYPE_STRING,	FALSE },
 	{ "Socket",			CONFIG_TYPE_STRING,	FALSE },
+	{ "SoftwareHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #ifdef _FFR_STATS
 	{ "Statistics",			CONFIG_TYPE_STRING,	FALSE },
 	{ "StatisticsName",		CONFIG_TYPE_STRING,	FALSE },
@@ -234,14 +236,9 @@ struct configdef dkimf_config[] =
 	{ "TemporaryDirectory",		CONFIG_TYPE_STRING,	FALSE },
 	{ "TestDNSData",		CONFIG_TYPE_STRING,	FALSE },
 	{ "TestPublicKeys",		CONFIG_TYPE_STRING,	FALSE },
-#ifdef USE_UNBOUND
 	{ "TrustAnchorFile",		CONFIG_TYPE_STRING,	FALSE },
-#endif /* USE_UNBOUND */
 	{ "TrustSignaturesFrom",	CONFIG_TYPE_STRING,	FALSE },
 	{ "UMask",			CONFIG_TYPE_INTEGER,	FALSE },
-#ifdef USE_UNBOUND
-	{ "UnboundConfigFile",		CONFIG_TYPE_STRING,	FALSE },
-#endif /* USE_UNBOUND */
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_VBR
 	{ "VBR-Certifiers",		CONFIG_TYPE_STRING,	FALSE },
