@@ -1,5 +1,5 @@
 /*
-**  Copyright (c) 2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2011, 2012, The Trusted Domain Project.  All rights reserved.
 */
 
 #include "build-config.h"
@@ -24,8 +24,10 @@
 # include <odbx.h>
 #endif /* USE_ODBX */
 
-/* libopendkim includes */
-#include <dkim-strl.h>
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 /* opendkim includes */
 #include "config.h"
@@ -33,7 +35,7 @@
 
 /* definitions, macros, etc. */
 #define	BUFRSZ		1024
-#define	CMDLINEOPTS	"b:c:d:fh:o:p:P:s:u:vV"
+#define	CMDLINEOPTS	"b:c:d:fh:o:p:P:r:s:u:vV"
 #define	DEFDBBACKEND	SQL_BACKEND
 #undef	DEFCONFFILE
 #define	DEFCONFFILE	CONFIG_BASE "/opendkim-spam.conf"
@@ -66,6 +68,8 @@ struct configdef spam_config[] =
 	{ "DatabasePassword",		CONFIG_TYPE_STRING,	FALSE },
 	{ "DatabaseSpamColumn",		CONFIG_TYPE_STRING,	FALSE },
 	{ "DatabaseUser",		CONFIG_TYPE_STRING,	FALSE },
+	{ "ReporterID",			CONFIG_TYPE_STRING,	FALSE },
+	{ "SkipReceived",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "StatisticsFile",		CONFIG_TYPE_STRING,	FALSE },
 	{ NULL,				(u_int) -1,		FALSE }
 };
@@ -94,6 +98,7 @@ usage(void)
 	        "\t-P dbport   \tdatabase port [%s]\n"
 	        "\t-s dbspamcol\tdatabase spam column name [%s]\n"
 	        "\t-u dbuser   \tdatabase user [%s]\n"
+		"\t-r reporter \treporter id (reporting host name)\n"
 	        "\t-v          \tbe more verbose\n"
 	        "\t-V          \tprint version number and exit\n",
 	        progname, progname,
@@ -128,6 +133,7 @@ main(int argc, char **argv)
 	int dberr;
 	int repid;
 	int msgid;
+	u_int skipcount = 0;
 	char *p;
 	char *prev;
 	char *dbbackend = NULL;
@@ -196,6 +202,10 @@ main(int argc, char **argv)
 			dbuser = optarg;
 			break;
 
+		  case 'r':
+			reporter = optarg;
+			break;
+
 		  case 'v':
 			verbose++;
 			break;
@@ -236,6 +246,9 @@ main(int argc, char **argv)
 		}
 
 		/* extract values */
+		(void) config_get(conf, "SkipReceived",
+		                  &skipcount, sizeof skipcount);
+
 		if (dbbackend == NULL)
 		{
 			(void) config_get(conf, "DatabaseBackend",
@@ -278,6 +291,12 @@ main(int argc, char **argv)
 			                  &dbuser, sizeof dbuser);
 		}
 
+		if (reporter == NULL)
+		{
+			(void) config_get(conf, "ReporterID",
+			                  &reporter, sizeof reporter);
+		}
+
 		if (statsfile == NULL)
 		{
 			(void) config_get(conf, "StatisticsFile",
@@ -374,20 +393,28 @@ main(int argc, char **argv)
 			}
 		}
 
-		if (rcvd[0] == '\0')
+		if (strncasecmp(buf, "Received:", 9) == 0)
 		{
-			if (strncasecmp(buf, "Received:", 9) == 0)
-				strlcat(rcvd, buf, sizeof rcvd);
+			if (skipcount > 0)
+			{
+				skipcount--;
+				continue;
+			}
+			else
+			{
+				strlcpy(rcvd, buf, sizeof rcvd);
+			}
 		}
-		else if (buf[0] == '\0' ||
-		         (isascii(buf[0]) && !isspace(buf[0])))
-		{
-			break;
-		}
-		else
+		else if (isascii(buf[0]) && isspace(buf[0]) &&
+		         rcvd[0] != '\0')
 		{
 			strlcat(rcvd, buf, sizeof rcvd);
 		}
+		else if (isascii(buf[0]) && !isspace(buf[0]) &&
+		         rcvd[0] != '\0')
+		{
+			break;
+		}
 	}
 
 	if (rcvd[0] == '\0')
@@ -425,7 +452,8 @@ main(int argc, char **argv)
 		{
 			if (strcasecmp(prev, "id") == 0)
 				job = p;
-			else if (strcasecmp(prev, "by") == 0)
+			else if (reporter == NULL &&
+			         strcasecmp(prev, "by") == 0)
 				reporter = p;
 		}
 
