@@ -2,18 +2,13 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: opendkim.h,v 1.34.10.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
 #ifndef _OPENDKIM_H_
 #define _OPENDKIM_H_
 
-#ifndef lint
-static char opendkim_h_id[] = "@(#)$Id: opendkim.h,v 1.34.10.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 #define	DKIMF_PRODUCT	"OpenDKIM Filter"
 #define	DKIMF_PRODUCTNS	"OpenDKIM-Filter"
 
@@ -69,7 +64,6 @@ static char opendkim_h_id[] = "@(#)$Id: opendkim.h,v 1.34.10.1 2010/10/27 21:43:
 #define	MAXSIGNATURE	1024
 #define	MTAMARGIN	78
 #define	NULLDOMAIN	"(invalid)"
-#define	TEMPFILE	"/var/tmp/dkimXXXXXX"
 #define	UNKNOWN		"unknown"
 
 #define	DB_DOMAINS	1
@@ -87,14 +81,14 @@ static char opendkim_h_id[] = "@(#)$Id: opendkim.h,v 1.34.10.1 2010/10/27 21:43:
 #define DKIMF_POLICY_NXDOMAIN	3		/* domain does not exist */
 
 #define AUTHRESULTSHDR	"Authentication-Results"
-#define ORCPTHEADER	"X-Original-Recipient"
+#define ORCPTHEADER	"Original-Recipient"
 
-#define	XHEADERNAME	"X-DKIM"
-#define	XSELECTCANONHDR	"X-Canonicalization"
+#define	SWHEADERNAME	"DKIM-Filter"
+#define	SELECTCANONHDR	"Canonicalization"
 
 #ifdef _FFR_VBR
-# define XVBRTYPEHEADER	"X-VBR-Type"
-# define XVBRCERTHEADER	"X-VBR-Certifiers"
+# define VBRTYPEHEADER	"VBR-Type"
+# define VBRCERTHEADER	"VBR-Certifiers"
 #endif /* _FFR_VBR */
 
 #ifdef _FFR_ADSP_LISTS
@@ -177,6 +171,7 @@ extern char *dkimf_get_ldap_param __P((int));
 
 #ifdef USE_LUA
 # ifdef DKIMF_LUA_PROTOTYPES
+extern void dkimf_import_globals __P((void *, lua_State *));
 extern int dkimf_xs_addheader __P((lua_State *));
 extern int dkimf_xs_addrcpt __P((lua_State *));
 extern int dkimf_xs_bodylength __P((lua_State *));
@@ -189,9 +184,7 @@ extern int dkimf_xs_dbopen __P((lua_State *));
 extern int dkimf_xs_dbquery __P((lua_State *));
 extern int dkimf_xs_delheader __P((lua_State *));
 extern int dkimf_xs_delrcpt __P((lua_State *));
-#  ifdef _FFR_LUA_GLOBALS
 extern int dkimf_xs_export __P((lua_State *));
-#  endif /* _FFR_LUA_GLOBALS */
 extern int dkimf_xs_fromdomain __P((lua_State *));
 extern int dkimf_xs_getenvfrom __P((lua_State *));
 extern int dkimf_xs_getheader __P((lua_State *));
