@@ -2,15 +2,10 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2011, 2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2011, 2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: reputation.c,v 1.27.2.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
-#ifndef lint
-static char reputation_c_id[] = "@(#)$Id: stats.c,v 1.27.2.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 #ifdef _FFR_REPUTATION
@@ -27,6 +22,11 @@ static char reputation_c_id[] = "@(#)$Id: stats.c,v 1.27.2.1 2010/10/27 21:43:09
 /* libopendkim includes */
 #include <dkim.h>
 
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
+
 /* opendkim includes */
 #include "reputation.h"
 #include "opendkim.h"
@@ -278,9 +278,9 @@ dkimf_rep_check(DKIMF_REP rep, DKIM_SIGINFO *sig, _Bool spam,
 	req[0].dbdata_flags = DKIMF_DB_DATA_BINARY;
 
 	if (sig == NULL)
-		dkim_strlcpy(domain, DKIMF_REP_NULLDOMAIN, sizeof domain);
+		strlcpy(domain, DKIMF_REP_NULLDOMAIN, sizeof domain);
 	else
-		dkim_strlcpy(domain, dkim_sig_getdomain(sig), sizeof domain);
+		strlcpy(domain, dkim_sig_getdomain(sig), sizeof domain);
 
 	dlen = strlen(domain);
 
@@ -336,7 +336,7 @@ dkimf_rep_check(DKIMF_REP rep, DKIM_SIGINFO *sig, _Bool spam,
 
 		if (lowtime)
 		{
-			dkim_strlcpy(domain, DKIMF_REP_LOWTIME, sizeof domain);
+			strlcpy(domain, DKIMF_REP_LOWTIME, sizeof domain);
 			dlen = strlen(domain);
 		}
 		
