@@ -2,15 +2,10 @@
 **  Copyright (c) 2007-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2011, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: test.c,v 1.15 2010/09/02 04:04:20 cm-msk Exp $
 */
 
-#ifndef lint
-static char test_c_id[] = "@(#)$Id: test.c,v 1.15 2010/09/02 04:04:20 cm-msk Exp $";
-#endif /* !lint */
-
 /* system includes */
 #include <sys/param.h>
 #include <sys/types.h>
@@ -26,7 +21,11 @@ static char test_c_id[] = "@(#)$Id: test.c,v 1.15 2010/09/02 04:04:20 cm-msk Exp
 /* libopendkim includes */
 #include "build-config.h"
 #include <dkim.h>
-#include <dkim-strl.h>
+
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 /* libmilter includes */
 #include <libmilter/mfapi.h>
@@ -381,7 +380,6 @@ dkimf_testfile(DKIM_LIB *libopendkim, struct test_context *tctx,
 	DKIM *dkim;
 	char *p;
 	sfsistat ms;
-	struct sockaddr_in sin;
 	char buf[MAXBUFRSZ];
 	char line[MAXBUFRSZ];
 
