@@ -2,15 +2,10 @@
 **  Copyright (c) 2005-2009 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  Copyright (c) 2009-2012, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009-2012, The Trusted Domain Project.  All rights reserved.
 **
-**  $Id: util.c,v 1.47.2.1 2010/10/27 21:43:09 cm-msk Exp $
 */
 
-#ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.47.2.1 2010/10/27 21:43:09 cm-msk Exp $";
-#endif /* !lint */
-
 #include "build-config.h"
 
 /* system includes */
@@ -52,8 +47,10 @@ static char util_c_id[] = "@(#)$Id: util.c,v 1.47.2.1 2010/10/27 21:43:09 cm-msk
 # endif /* SOLARIS <= 20600 */
 #endif /* SOLARIS */
 
-/* libopendkim includes */
-#include <dkim-strl.h>
+/* libstrl if needed */
+#ifdef USE_STRL_H
+# include <strl.h>
+#endif /* USE_STRL_H */
 
 /* opendkim includes */
 #include "opendkim.h"
@@ -91,10 +88,6 @@ static char *optlist[] =
 	"QUERY_CACHE",
 #endif /* QUERY_CACHE */
 
-#if USE_ARLIB
-	"USE_ARLIB",
-#endif /* USE_ARLIB */
-
 #if USE_DB
 	"USE_DB",
 #endif /* USE_DB */
@@ -159,14 +152,6 @@ static char *optlist[] =
 	"_FFR_LDAP_CACHING",
 #endif /* _FFR_LDAP_CACHING */
 
-#if _FFR_LUA_GLOBALS
-	"_FFR_LUA_GLOBALS",
-#endif /* _FFR_LUA_GLOBALS */
-
-#if _FFR_OVERSIGN
-	"_FFR_OVERSIGN",
-#endif /* _FFR_OVERSIGN */
-
 #if _FFR_POSTGRESQL_RECONNECT_HACK
 	"_FFR_POSTGRESQL_RECONNECT_HACK",
 #endif /* _FFR_POSTGRESQL_RECONNECT_HACK */
@@ -187,14 +172,14 @@ static char *optlist[] =
 	"_FFR_REPLACE_RULES",
 #endif /* _FFR_REPLACE_RULES */
 
+#if _FFR_REPRRD
+	"_FFR_REPRRD",
+#endif /* _FFR_REPRRD */
+
 #if _FFR_REPUTATION
 	"_FFR_REPUTATION",
 #endif /* _FFR_REPUTATION */
 
-#if _FFR_REPUTATION_CACHE
-	"_FFR_REPUTATION_CACHE",
-#endif /* _FFR_REPUTATION_CACHE */
-
 #if _FFR_RESIGN
 	"_FFR_RESIGN",
 #endif /* _FFR_RESIGN */
@@ -1397,6 +1382,7 @@ size_t
 dkimf_dstring_printf(struct dkimf_dstring *dstr, char *fmt, ...)
 {
 	size_t len;
+	size_t rem;
 	va_list ap;
 	va_list ap2;
 
@@ -1405,20 +1391,21 @@ dkimf_dstring_printf(struct dkimf_dstring *dstr, char *fmt, ...)
 
 	va_start(ap, fmt);
 	va_copy(ap2, ap);
-	len = vsnprintf((char *) dstr->ds_buf + dstr->ds_len, dstr->ds_alloc,
-	                fmt, ap);
+	rem = dstr->ds_alloc - dstr->ds_len;
+	len = vsnprintf((char *) dstr->ds_buf + dstr->ds_len, rem, fmt, ap);
 	va_end(ap);
 
-	if (len > dstr->ds_len)
+	if (len > rem)
 	{
-		if (!dkimf_dstring_resize(dstr, len + 1))
+		if (!dkimf_dstring_resize(dstr, dstr->ds_len + len + 1))
 		{
 			va_end(ap2);
 			return (size_t) -1;
 		}
 
-		len = vsnprintf((char *) dstr->ds_buf + dstr->ds_len,
-		                dstr->ds_alloc, fmt, ap2);
+		rem = dstr->ds_alloc - dstr->ds_len;
+		len = vsnprintf((char *) dstr->ds_buf + dstr->ds_len, rem,
+		                fmt, ap2);
 	}
 
 	va_end(ap2);
